@@ -732,6 +732,9 @@ class GeometryArray(ExtensionArray):
 
     @property
     def bounds(self):
+        # ensure that for empty arrays, the result has the correct shape
+        if len(self) == 0:
+            return np.empty((0, 4), dtype="float64")
         # need to explicitly check for empty (in addition to missing) geometries,
         # as those return an empty tuple, not resulting in a 2D array
         bounds = np.array(
@@ -746,6 +749,10 @@ class GeometryArray(ExtensionArray):
 
     @property
     def total_bounds(self):
+        if len(self) == 0:
+            # numpy 'min' cannot handle empty arrays
+            # TODO with numpy >= 1.15, the 'initial' argument can be used
+            return np.array([np.nan, np.nan, np.nan, np.nan])
         b = self.bounds
         return np.array(
             (
