@@ -72,11 +72,17 @@ class GeoDataFrame(GeoPandasBase, DataFrame):
         # TODO do we want to raise / return normal DataFrame in this case?
         if geometry is None and "geometry" in self.columns:
             # only if we have actual geometry values -> call set_geometry
+            index = self.index
             try:
                 self["geometry"] = _ensure_geometry(self["geometry"].values)
             except TypeError:
                 pass
             else:
+                if self.index is not index:
+                    # With pandas < 1.0 and an empty frame (no rows), the index
+                    # gets reset to a default RangeIndex -> set back the original
+                    # index if needed
+                    self.index = index
                 geometry = "geometry"
 
         if geometry is not None:
@@ -173,7 +179,12 @@ class GeoDataFrame(GeoPandasBase, DataFrame):
 
         # Check that we are using a listlike of geometries
         level = _ensure_geometry(level)
+        index = frame.index
         frame[geo_column_name] = level
+        if frame.index is not index and len(frame.index) == len(index):
+            # With pandas < 1.0 and an empty frame (no rows), the index gets reset
+            # to a default RangeIndex -> set back the original index if needed
+            frame.index = index
         frame._geometry_column_name = geo_column_name
         frame.crs = crs
         frame._invalidate_sindex()
